# rawtypes

code generator for python extension

## clang.cindex

This library is use 'clang.cindex` from <https://raw.githubusercontent.com/llvm/llvm-project/llvmorg-13.0.0/clang/bindings/python/clang/>.
And placement in rawtypes.clang.

```py
from rawtypes.clang import cindex
```
